@@ -1,3 +1,6 @@
+from pkgutil import extend_path
+__path__ = extend_path(__path__, __name__)
+
 import abc
 import builtins
 import datetime
@@ -16,7 +19,7 @@ import cdktf_cdktf_provider_kubernetes._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "cdktf-cdk8s", "0.5.1", __name__[0:-6], "cdktf-cdk8s@0.5.1.jsii.tgz"
+    "cdktf-cdk8s", "0.10.30", __name__[0:-6], "cdktf-cdk8s@0.10.30.jsii.tgz"
 )
 
 __all__ = [
